Pyjamas Web development actually has more in common with Python-Qt4 and Python-GTK2 than it does with "traditional" web development. The base widgets (of which there are over 50) have almost exact corresponding analogues in Desktop Widget sets. The nice thing about Pyjamas, though, when compared to the Desktop Widget frameworks is that you get "true" HTML / CSS interoperability, and "true" plugin support such as Adobe Flash, all for free.